function M=mpipe2_fancy(s,T,alpha,Z,np)
%mpipe2_fancy Calculate the elements of the four terminal network for a set of parallel pipes
%	This function needs s=j*w, T=L/a, alpha=32mu/D^2rho, Z=rho*a/A, 
%   and np, the number of equally sized pipes
%	M=mpipe2_fancy(s,T,alpha,Z,np)
%
%   uses a more elaborate method for computing N which gives more accurate
%     response for pipeline resonances at high frequency see pg 143, eqn 6e
%
%	DeBra 1988 may 5 ref Taco Viersma pg 146

%N=1+alpha/s;
soa = s/alpha;
N = 1 + alpha/s + .1918/(1+.2496*soa) + .0948/(1+ .0352*soa) + .0407/(1+.0024*soa);

sqn=sqrt(N);
tsn=T*s*sqn;
A=cosh(tsn);
zn=Z*sqn;
B=-np*sinh(tsn)/zn;
C=-sinh(tsn)*zn/np;
D=A;

M=[A B; C D];
